@@ -1,8 +1,8 @@
 // Copyright (C) 2016 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only
 
-#ifndef QSURFACE3DSERIES_H
-#define QSURFACE3DSERIES_H
+#ifndef QTDATAVIS3D_QSURFACE3DSERIES_H
+#define QTDATAVIS3D_QSURFACE3DSERIES_H
 
 #include <QtDataVisualization/qabstract3dseries.h>
 #include <QtDataVisualization/qsurfacedataproxy.h>
